# FELON FINDER

This application aims to facilitate the recognition of a potential assailant by producing composite sketches.

## Table of contents
* [General info](#general-info-)
* [Installation, Documentation, Q&A](#installation-documentation-qa-)

### General info :
***

When launching FELON FINDER, four randomly selected images from our database (celebA dataset) are presented to the user.

The user selects the most similar images. They can choose from one to four photos each time.

By clicking on the "Valider" button, the selected images are then processed to produce four new composite sketches that increasingly resemble the assailant.

Once the user has identified a suitable sketch, they can save the image.

The software is currently only available in French.

### Installation, Documentation, Q&A :
***

[Read the documentation](https://alexandrelayous.github.io/felon-finder/)